@@ -149,7 +149,7 @@ class Estimator(AbstractEstimator):
             if self.__last_len != len(X):
                 start_index = -(self.__last_len - len(X))
                 Xl = X[start_index:]
-                yl = y[start_index]
+                yl = y[start_index:]
                 Xl = Xl.astype("int64").reshape(-1, len(design_point))
                 if self.__metrics:
                     yl = yl.astype("float64").reshape(-1, len(self.__metrics))
@@ -222,7 +222,22 @@ class Estimator(AbstractEstimator):
             opened_file.write(line[:-1] + "\n")
             opened_file.close()
 
-    def __generate_dataset(self,) -> None:
+    @staticmethod
+    def evaluate_random_design_point(
+        free_parameters_range: "OrderedDict[str, Tuple[int, int]]",
+        evaluator: AbstractDesignPointEvaluator,
+    ) -> Tuple[List[int], DesignValue]:
+
+        design_point = []
+        for k in free_parameters_range.keys():
+            design_point.append(
+                randint(
+                    free_parameters_range[k][0], free_parameters_range[k][1],
+                )
+            )
+        return design_point, evaluator.evaluate(tuple(design_point))
+
+    def __generate_dataset(self) -> None:
         design_value = None
         if self.__reading_design_values:
             lines = (
@@ -241,7 +256,7 @@ class Estimator(AbstractEstimator):
                     design_point = []
                     splitted_line = line.split(",")
                     i = 0
-                    for k in self.__free_parameters_range.keys():
+                    for _ in self.__free_parameters_range.keys():
                         design_point.append(float(splitted_line[i]))
                         i += 1
 
@@ -273,16 +288,11 @@ class Estimator(AbstractEstimator):
             return
 
         for _ in range(0, self.__dataset_size):
-            design_point = []
-            for k in self.__free_parameters_range.keys():
-                design_point.append(
-                    randint(
-                        self.__free_parameters_range[k][0],
-                        self.__free_parameters_range[k][1],
-                    )
-                )
-            design_value = self.__design_point_evaluator.evaluate(
-                tuple(design_point)
+            (
+                design_point,
+                design_value,
+            ) = Estimator.evaluate_random_design_point(
+                self.__free_parameters_range, self.__design_point_evaluator
             )
             if design_value:
                 self.add_example(
