@@ -89,7 +89,7 @@ def dovado(
     target_clock: float = typer.Option(
         default=1000,
         callback=validate_target_clock,
-        help="target clock on which the worst negative slack is computed,"
+        help="target clock (Mhz) on which the worst negative slack is computed,"
         + "make sure this is sufficiently large to never be reached by your design",
     ),
 ):  # pylint: disable=too-many-arguments
@@ -221,6 +221,13 @@ def space(
         help="list of integers in which each odd indexed element starts"
         + " a range and the consecutive closes it (start counting from 1)",
     ),
+    param_initial_values: Optional[List[int]] = typer.Option(
+        None,
+        help="state initial values for parameters which are guaranteed to synthesize/implement",
+    ),
+    optimization_runtime: Optional[str] = typer.Option(
+        None, help="optimization timeout as hh:mm:ss"
+    ),
     approximate: bool = typer.Option(
         False, help="enable approximations for fitness function"
     ),
@@ -228,7 +235,8 @@ def space(
         "KERNEL_RIDGE",
         callback=validate_estimator,
         help="estimator to use for fitness function approximation,"
-        + "'kernel_ridge' is default. 'stream_learning' selects a Hoeffding Adaptive Tree Regressor trained incrementally",
+        + "'kernel_ridge' is default. 'stream_learning_isoup' selects a ISOUP Adaptive Tree Regressor trained incrementally "
+        + "while 'stream_learning_stacked' selects a Stacked tree regressor",
     ),
     nearest_distance: int = typer.Option(
         3,
@@ -254,24 +262,53 @@ def space(
     """
     it = iter(param_ranges)
     ranges_dict = OrderedDict(zip(ctx.obj["parameters"], zip(it, it)))
-
-    estimator = Estimator(
-        RegressionModel.STREAM_LEARNING_ISOUP
-        if fitness_estimator.upper() == "STREAM_LEARNING_ISOUP"
-        else RegressionModel.STREAM_LEARNING_STACKED
-        if fitness_estimator.upper() == "STREAM_LEARNING_STACKED"
-        else RegressionModel.KERNEL_RIDGE,
-        ctx.obj["point_evaluator"],
-        ranges_dict,
-        int(ctx.obj["config"].get_config("INITIAL_SAMPLES")),
-        ctx.obj["config"],
-        test_estimation,
-        record_design_values,
-        read_design_values,
-    )
+    estimator = None
+    if approximate:
+        estimator = Estimator(
+            RegressionModel.STREAM_LEARNING_ISOUP
+            if fitness_estimator.upper() == "STREAM_LEARNING_ISOUP"
+            else RegressionModel.STREAM_LEARNING_STACKED
+            if fitness_estimator.upper() == "STREAM_LEARNING_STACKED"
+            else RegressionModel.KERNEL_RIDGE,
+            ctx.obj["point_evaluator"],
+            ranges_dict,
+            int(ctx.obj["config"].get_config("INITIAL_SAMPLES")),
+            ctx.obj["config"],
+            test_estimation,
+            record_design_values,
+            read_design_values,
+        )
+    else:
+        if param_initial_values:
+            design_value = ctx.obj["point_evaluator"].evaluate(
+                tuple(param_initial_values)
+            )
+            if not design_value:
+                raise Exception(
+                    "Could not synthesize/implement "
+                    + str(param_initial_values)
+                )
+        else:
+            # first estimation is to retrieve available utilization metrics
+            (
+                design_point,
+                design_value,
+            ) = Estimator.evaluate_random_design_point(
+                ranges_dict, ctx.obj["point_evaluator"]
+            )
+            i = 0
+            while (not design_value) and (i < 10):
+                print("Could not synthesize/implement " + str(design_point))
+                _, design_value = Estimator.evaluate_random_design_point(
+                    ranges_dict, ctx.obj["point_evaluator"]
+                )
+                i += 1
+            if i == 10:
+                raise Exception(
+                    "Could not find a valid design point in 10 attempts"
+                )
 
     fitness_evaluator = FitnessEvaluator(
-        approximate,
         nearest_distance,
         estimator,
         ctx.obj["point_evaluator"],
@@ -288,10 +325,7 @@ def space(
         )
 
     result = optimize(
-        fitness_evaluator,
-        ranges_dict,
-        metrics,
-        str(ctx.obj["config"].get_config("GENETIC_RUN_TIME")),
+        fitness_evaluator, ranges_dict, metrics, optimization_runtime,
     )
     print("Optimization Result: " + str(result))
 
